# sidecar

![build](https://gitlab.33.cn/link33/sidecar/workflows/build/badge.svg)
[![codecov](https://codecov.io/gh/link33/sidecar/branch/master/graph/badge.svg)](https://codecov.io/gh/link33/sidecar)

## Build

Using the follow command to install necessary tools.

```bash
make prepare
```

And then install sidecar using the following command.

```bash
make install
```

## Initialization

Using the follow command to initialize sidecar.
```bash
sidecar init
```
Default repo path is `~/sidecar`. If you want to specify the repo path, you can use `--repo` flag.

```bash
sidecar init --repo=$HOME/sidecar
```

Run server

```bash
sidecar start
```

After initializing sidecar, it will generate the follow directory:

```
~/sidecar » tree                                                                                                                                                                              suyanlong@suyanlongdeMacBook-Pro-2
.
├── api
├── certs
│   └── ca.pem
├── key.json
├── logs
│   ├── sidecar.log -> /Users/suyanlong/sidecar/logs/sidecar.log20211116000000
│   └── sidecar.log20211116000000
├── node.priv
├── plugins
│   ├── chain33
│   │   └── chain33.toml
│   └── chain33-client
├── pprof
│   ├── cpu-20211116-10:53:17
│   ├── cpu-20211116-11:04:56
│   ├── mem-20211116-10:53:17
│   └── mem-20211116-11:04:56
├── sidecar.toml
└── store
    ├── 000074.log
    ├── CURRENT
    ├── CURRENT.bak
    ├── LOCK
    ├── LOG
    └── MANIFEST-000075

```

## Configuration

```toml
title = "Sidecar"

[port]
http = 44544
pprof = 44555

[log]
level = "info"
dir = "logs"
filename = "sidecar.log"
report_caller = false

[log.module]
app          = "info"
manager      = "info"
api_server   = "info"
appchain_mgr = "info"
rule_mgr     = "info"
peer_mgr     = "info"
router       = "info"
swarm        = "info"
syncer       = "info"

[[appchains]]
enable = true
type = "appchain"
did = "did:bitxhub:chain33:."
plugin = "chain33-client"
config = "chain33"
plugin_id = "chain33"

[peer]
peers = ["/ip4/127.0.0.1/tcp/4000/p2p/QmeRiU3Nh7RDrVjG9XP4tPhVewk3Pa4S63fhHpymSNchoA","/ip4/127.0.0.1/tcp/4001/ipfs/QmfC33rPPobCDo1WBhAy8VG6ocTiLfZzFb8aaQGqv3MVv3","/ip4/127.0.0.1/tcp/4002/ipfs/QmVtRucwZjzLb2AEd4CRZ2nheLrDEuUymG8zKsfxdg2pic"]
connectors = ["localhost:60011", "localhost:60012", "localhost:60013", "localhost:60014"]
providers = 1

```

`port.pprof`: the pprof server port

`log.level`: log level: debug, info, warn, error, fatal

`appchain.plugin`: relative path in sidecar repo of appchain plugin

`appchain.config`: relative path of appchain config directory

